// Copyright (c) Shenyang Leading Edge Intelligent Technology Co., Ltd. All rights reserved.

package me

import (
	"LAPP_ACURA_MOM_BACKEND/grmi"
	svr "LAPP_ACURA_MOM_BACKEND/services/me"
	"github.com/kataras/iris/v12/core/router"
)

/******************************************************************************
 *
 * @Interface Name           : RegisterRoutes
 *-----------------------------------------------------------------------------
 *
 * @Description              : 注册路由
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 15:30:32
 *
 ******************************************************************************/
func RegisterRoutes() {
	// 模块me路由分组
	grmi.RegisterRouteMapping("/me", func(party router.Party) {

		// Project的路由组
		project := party.Party("/project")
		// Project的服务实例
		var serviceOfProject = svr.NewProjectService()
		// Project插入一条
		RegisterInsertOneProject(project, "/insertone", serviceOfProject.InsertOne)
		// Project插入多条
		// RegisterInsertProject(project, "/insert", serviceOfProject.Insert)
		// Project删除一条
		RegisterDeleteOneProject(project, "/deleteone", serviceOfProject.DeleteOne)
		// Project删除多条
		// RegisterDeleteProject(project, "/delete", serviceOfProject.Delete)
		// Project查询多条
		RegisterSelectProject(project, "/query", serviceOfProject.Select)
		// Project查询一条
		RegisterSelectOneProject(project, "/get", serviceOfProject.SelectOne)
		// Project修改一条
		RegisterUpdateOneProject(project, "/updateone", serviceOfProject.UpdateOne)
		// Project修改多条
		// RegisterUpdateProject(project, "/update", serviceOfProject.Update)

		// ProductFamily的路由组
		productfamily := party.Party("/productfamily")
		// ProductFamily的服务实例
		var serviceOfProductFamily = svr.NewProductFamilyService()
		// ProductFamily插入一条
		RegisterInsertOneProductFamily(productfamily, "/insertone", serviceOfProductFamily.InsertOne)
		// ProductFamily插入多条
		// RegisterInsertProductFamily(productfamily, "/insert", serviceOfProductFamily.Insert)
		// ProductFamily删除一条
		RegisterDeleteOneProductFamily(productfamily, "/deleteone", serviceOfProductFamily.DeleteOne)
		//配置关联产品重置
		RegisterAssociationProductFamily(productfamily, "/association", serviceOfProductFamily.Association)
		// ProductFamily删除多条
		// RegisterDeleteProductFamily(productfamily, "/delete", serviceOfProductFamily.Delete)
		// ProductFamily查询多条
		RegisterSelectProductFamily(productfamily, "/selectlist", serviceOfProductFamily.Select)
		// ProductFamily查询多条并分页
		RegisterQueryProductFamily(productfamily, "/query", serviceOfProductFamily.SelectAndPaging)
		// ProductFamily查询一条
		RegisterSelectOneProductFamily(productfamily, "/selectone", serviceOfProductFamily.SelectOne)
		// ProductFamily修改一条
		RegisterUpdateOneProductFamily(productfamily, "/updateone", serviceOfProductFamily.UpdateOne)
		// ProductFamily修改多条
		// RegisterUpdateProductFamily(productfamily, "/update", serviceOfProductFamily.Update)
		// ProductFamily 生成包装模板
		RegisterGeneratePackTemplateByProductFamily(productfamily, "/generatetemplate", serviceOfProductFamily.GeneratePackTemplate)
		// ProductFamily上传excel导入数据
		RegisterProductFamilyUploadExcel(productfamily, "/uploadexcel", serviceOfProductFamily.ImportFromExcel)
		// ProductFamily 查询可生产的产线
		RegisterProductFamilySelectWorkLine(productfamily, "/selectworkline", serviceOfProductFamily.SelectCanProductWorkLine)

		// Product的路由组
		product := party.Party("/product")
		// Product的服务实例
		var serviceOfProduct = svr.NewProductService()
		// Product插入一条
		RegisterInsertOneProduct(product, "/insertone", serviceOfProduct.InsertOne)
		// Product插入多条
		// RegisterInsertProduct(product, "/insert", serviceOfProduct.Insert)
		// Product删除一条
		RegisterDeleteOneProduct(product, "/deleteone", serviceOfProduct.DeleteOne)

		RegisterCancelProduct(product, "/cancel", serviceOfProduct.Cancel)
		// Product删除多条
		// RegisterDeleteProduct(product, "/delete", serviceOfProduct.Delete)
		// Product查询多条
		RegisterSelectProduct(product, "/selectlist", serviceOfProduct.Select)
		// Product查询多条并分页
		RegisterQueryProduct(product, "/query", serviceOfProduct.SelectAndPaging)
		// Product查询一条
		RegisterSelectOneProduct(product, "/selectone", serviceOfProduct.SelectOne)
		// Product修改一条
		RegisterUpdateOneProduct(product, "/updateone", serviceOfProduct.UpdateOne)
		// Product修改多条
		// RegisterUpdateProduct(product, "/update", serviceOfProduct.Update)
		// Product修改多条
		RegisterSelectProductByWorkLine(product, "/selectbyworkline", serviceOfProduct.SelectByWorkLine)
		// Product 复制
		RegisterCopyProduct(product, "/copy", serviceOfProduct.Copy)
		// Product 通过总成查询产线
		RegisterSelectWorkLineByProduct(product, "/selectworkline", serviceOfProduct.SelectWorkLineByProduct)

		// SetupMatrix的路由组
		setupmatrix := party.Party("/setupmatrix")
		// SetupMatrix的服务实例
		var serviceOfSetupMatrix = svr.NewSetupMatrixService()
		// SetupMatrix插入一条
		RegisterInsertOneSetupMatrix(setupmatrix, "/insertone", serviceOfSetupMatrix.InsertOne)
		// SetupMatrix插入多条
		// RegisterInsertSetupMatrix(setupmatrix, "/insert", serviceOfSetupMatrix.Insert)
		// SetupMatrix删除一条
		RegisterDeleteOneSetupMatrix(setupmatrix, "/deleteone", serviceOfSetupMatrix.DeleteOne)
		// SetupMatrix删除多条
		// RegisterDeleteSetupMatrix(setupmatrix, "/delete", serviceOfSetupMatrix.Delete)
		// SetupMatrix查询多条
		RegisterSelectSetupMatrix(setupmatrix, "/query", serviceOfSetupMatrix.Select)
		// SetupMatrix查询一条
		RegisterSelectOneSetupMatrix(setupmatrix, "/get", serviceOfSetupMatrix.SelectOne)
		// SetupMatrix修改一条
		RegisterUpdateOneSetupMatrix(setupmatrix, "/updateone", serviceOfSetupMatrix.UpdateOne)
		// SetupMatrix修改多条
		// RegisterUpdateSetupMatrix(setupmatrix, "/update", serviceOfSetupMatrix.Update)

		// BomHead的路由组
		bomhead := party.Party("/bomhead")
		// BomHead的服务实例
		var serviceOfBomHead = svr.NewBomHeadService()
		// BomHead插入一条
		RegisterInsertOneBomHead(bomhead, "/insertone", serviceOfBomHead.InsertOne)
		// BomHead插入多条
		// RegisterInsertBomHead(bomhead, "/insert", serviceOfBomHead.Insert)
		// BomHead删除一条
		RegisterDeleteOneBomHead(bomhead, "/deleteone", serviceOfBomHead.DeleteOne)
		// BomHead删除多条
		// RegisterDeleteBomHead(bomhead, "/delete", serviceOfBomHead.Delete)
		// BomHead查询多条
		RegisterSelectBomHead(bomhead, "/query", serviceOfBomHead.Select)
		// BomHead查询一条
		RegisterSelectOneBomHead(bomhead, "/get", serviceOfBomHead.SelectOne)
		// BomHead修改一条
		RegisterUpdateOneBomHead(bomhead, "/updateone", serviceOfBomHead.UpdateOne)
		// BomHead修改多条
		// RegisterUpdateBomHead(bomhead, "/update", serviceOfBomHead.Update)
		// BomHead 复制bom
		RegisterCopyBom(bomhead, "/copy", serviceOfBomHead.Copy)
		// BomHead 通过文件导入数据
		RegisterBomHeadUploadExcel(bomhead, "/uploadexcel", serviceOfBomHead.ImportFromExcel)

		// BomLst的路由组
		bomlst := party.Party("/bomlst")
		// BomLst的服务实例
		var serviceOfBomLst = svr.NewBomLstService()
		// BomLst插入一条
		RegisterInsertOneBomLst(bomlst, "/insertone", serviceOfBomLst.InsertOne)
		// BomLst插入多条
		// RegisterInsertBomLst(bomlst, "/insert", serviceOfBomLst.Insert)
		// BomLst删除一条
		RegisterDeleteOneBomLst(bomlst, "/deleteone", serviceOfBomLst.DeleteOne)
		// BomLst删除多条
		// RegisterDeleteBomLst(bomlst, "/delete", serviceOfBomLst.Delete)
		// BomLst查询多条
		RegisterSelectBomLst(bomlst, "/query", serviceOfBomLst.Select)
		// BomLst查询一条
		RegisterSelectOneBomLst(bomlst, "/get", serviceOfBomLst.SelectOne)
		// BomLst修改一条
		RegisterUpdateOneBomLst(bomlst, "/updateone", serviceOfBomLst.UpdateOne)
		// BomLst修改多条
		// RegisterUpdateBomLst(bomlst, "/update", serviceOfBomLst.Update)

		// ProductFamilyRelate的路由组
		productfamilyrelate := party.Party("/productfamilyrelate")
		// ProductFamilyRelate的服务实例
		var serviceOfProductFamilyRelate = svr.NewProductFamilyRelateService()
		// ProductFamilyRelate插入一条
		// RegisterInsertOneProductFamilyRelate(productfamilyrelate, "/insertone", serviceOfProductFamilyRelate.InsertOne)
		// ProductFamilyRelate插入多条
		// RegisterInsertProductFamilyRelate(productfamilyrelate, "/insert", serviceOfProductFamilyRelate.Insert)
		// ProductFamilyRelate删除一条
		// RegisterDeleteOneProductFamilyRelate(productfamilyrelate, "/deleteone", serviceOfProductFamilyRelate.DeleteOne)
		// ProductFamilyRelate删除多条
		// RegisterDeleteProductFamilyRelate(productfamilyrelate, "/delete", serviceOfProductFamilyRelate.Delete)
		// ProductFamilyRelate查询多条
		RegisterSelectProductFamilyRelate(productfamilyrelate, "/selectlist", serviceOfProductFamilyRelate.Select)
		// ProductFamilyRelate查询多条并分页
		RegisterQueryProductFamilyRelate(productfamilyrelate, "/query", serviceOfProductFamilyRelate.SelectAndPaging)
		// ProductFamilyRelate查询一条
		RegisterSelectOneProductFamilyRelate(productfamilyrelate, "/selectone", serviceOfProductFamilyRelate.SelectOne)
		// ProductFamilyRelate修改一条
		// RegisterUpdateOneProductFamilyRelate(productfamilyrelate, "/updateone", serviceOfProductFamilyRelate.UpdateOne)
		// ProductFamilyRelate修改多条
		// RegisterUpdateProductFamilyRelate(productfamilyrelate, "/update", serviceOfProductFamilyRelate.Update)
		// ProductFamilyRelate 上传excel导入数据
		RegisterProductFamilyRelateUploadExcel(productfamilyrelate, "/uploadexcel", serviceOfProductFamilyRelate.ImportFromExcel)

		// ProductWorkLineLst的路由组
		productworklinelst := party.Party("/productworklinelst")
		// ProductWorkLineLst的服务实例
		var serviceOfProductWorkLineLst = svr.NewProductWorkLineLstService()
		// ProductWorkLineLst插入一条
		//RegisterInsertOneProductWorkLineLst(productworklinelst, "/insertone", serviceOfProductWorkLineLst.InsertOne)
		// ProductWorkLineLst插入多条
		// RegisterInsertProductWorkLineLst(productworklinelst, "/insert", serviceOfProductWorkLineLst.Insert)
		// ProductWorkLineLst删除一条
		//RegisterDeleteOneProductWorkLineLst(productworklinelst, "/deleteone", serviceOfProductWorkLineLst.DeleteOne)
		// ProductWorkLineLst删除多条
		// RegisterDeleteProductWorkLineLst(productworklinelst, "/delete", serviceOfProductWorkLineLst.Delete)
		// ProductWorkLineLst查询多条
		RegisterSelectProductWorkLineLst(productworklinelst, "/selectlist", serviceOfProductWorkLineLst.Select)
		// ProductWorkLineLst查询多条并分页
		RegisterQueryProductWorkLineLst(productworklinelst, "/query", serviceOfProductWorkLineLst.SelectAndPaging)
		// ProductWorkLineLst查询一条
		RegisterSelectOneProductWorkLineLst(productworklinelst, "/selectone", serviceOfProductWorkLineLst.SelectOne)
		// ProductWorkLineLst修改一条
		//RegisterUpdateOneProductWorkLineLst(productworklinelst, "/updateone", serviceOfProductWorkLineLst.UpdateOne)
		// ProductWorkLineLst修改多条
		// RegisterUpdateProductWorkLineLst(productworklinelst, "/update", serviceOfProductWorkLineLst.Update)
		// ProductWorkLineLst 保存关联关系
		RegisterSaveProductWorkLineLst(productworklinelst, "/save", serviceOfProductWorkLineLst.Save)

		// ShipableAUConfig的路由组
		shipableauconfig := party.Party("/shipableauconfig")
		// ShipableAUConfig的服务实例
		var serviceOfShipableAUConfig = svr.NewShipableAUConfigService()
		// ShipableAUConfig插入一条
		// RegisterInsertOneShipableAUConfig(shipableauconfig, "/insertone", serviceOfShipableAUConfig.InsertOne)
		// ShipableAUConfig插入多条
		// RegisterInsertShipableAUConfig(shipableauconfig, "/insert", serviceOfShipableAUConfig.Insert)
		// ShipableAUConfig删除一条
		// RegisterDeleteOneShipableAUConfig(shipableauconfig, "/deleteone", serviceOfShipableAUConfig.DeleteOne)
		// ShipableAUConfig删除多条
		// RegisterDeleteShipableAUConfig(shipableauconfig, "/delete", serviceOfShipableAUConfig.Delete)
		// ShipableAUConfig查询多条
		//RegisterSelectShipableAUConfig(shipableauconfig, "/selectlist", serviceOfShipableAUConfig.Select)
		// ShipableAUConfig查询多条并分页
		//RegisterQueryShipableAUConfig(shipableauconfig, "/query", serviceOfShipableAUConfig.SelectAndPaging)
		// ShipableAUConfig查询一条
		RegisterSelectOneShipableAUConfig(shipableauconfig, "/selectone", serviceOfShipableAUConfig.SelectOne)
		// ShipableAUConfig修改一条
		// RegisterUpdateOneShipableAUConfig(shipableauconfig, "/updateone", serviceOfShipableAUConfig.UpdateOne)
		// ShipableAUConfig修改多条
		// RegisterUpdateShipableAUConfig(shipableauconfig, "/update", serviceOfShipableAUConfig.Update)
		// ShipableAUConfig 保存一条
		RegisterSaveShipableAUConfig(shipableauconfig, "/save", serviceOfShipableAUConfig.Save)

		// ProductFamilyWorkLineLst的路由组
		productfamilyworklinelst := party.Party("/productfamilyworklinelst")
		// ProductFamilyWorkLineLst的服务实例
		var serviceOfProductFamilyWorkLineLst = svr.NewProductFamilyWorkLineLstService()
		// ProductFamilyWorkLineLst插入一条
		// RegisterInsertOneProductFamilyWorkLineLst(productfamilyworklinelst, "/insertone", serviceOfProductFamilyWorkLineLst.InsertOne)
		// ProductFamilyWorkLineLst插入多条
		// RegisterInsertProductFamilyWorkLineLst(productfamilyworklinelst, "/insert", serviceOfProductFamilyWorkLineLst.Insert)
		// ProductFamilyWorkLineLst删除一条
		// RegisterDeleteOneProductFamilyWorkLineLst(productfamilyworklinelst, "/deleteone", serviceOfProductFamilyWorkLineLst.DeleteOne)
		// ProductFamilyWorkLineLst删除多条
		// RegisterDeleteProductFamilyWorkLineLst(productfamilyworklinelst, "/delete", serviceOfProductFamilyWorkLineLst.Delete)
		// ProductFamilyWorkLineLst查询多条
		RegisterSelectProductFamilyWorkLineLst(productfamilyworklinelst, "/selectlist", serviceOfProductFamilyWorkLineLst.Select)
		// ProductFamilyWorkLineLst查询多条并分页
		RegisterQueryProductFamilyWorkLineLst(productfamilyworklinelst, "/query", serviceOfProductFamilyWorkLineLst.SelectAndPaging)
		// ProductFamilyWorkLineLst查询一条
		RegisterSelectOneProductFamilyWorkLineLst(productfamilyworklinelst, "/selectone", serviceOfProductFamilyWorkLineLst.SelectOne)
		// ProductFamilyWorkLineLst修改一条
		// RegisterUpdateOneProductFamilyWorkLineLst(productfamilyworklinelst, "/updateone", serviceOfProductFamilyWorkLineLst.UpdateOne)
		// ProductFamilyWorkLineLst修改多条
		// RegisterUpdateProductFamilyWorkLineLst(productfamilyworklinelst, "/update", serviceOfProductFamilyWorkLineLst.Update)
		// RegisterSaveFamilyWorkLineLst 保存派生和产线关联关系
		RegisterSaveFamilyWorkLineLst(productfamilyworklinelst, "/save", serviceOfProductFamilyWorkLineLst.Save)

	})
}

/******************************************************************************
 *
 * @Interface Name           : init
 *-----------------------------------------------------------------------------
 *
 * @Description              : 包初始化方法
 *
 * @Author                   : 代码生成器创建
 *
 * @Date                     : 2021-10-22 15:30:32
 *
 ******************************************************************************/
func init() {

	// 注册路由
	RegisterRoutes()
}
